Transifex documentation — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

# Transifex documentation

Welcome to the documentation of Transifex, the open localization platform.

Version: | 0.9
Release: | 0.9.0
Date: | July 19, 2010

Transifex is a modern, open-source localization platform. It’s a web system which automates the translation workflow of complex international projects.

To use Transifex, visit Transifex.net, our one-stop, batteries-included service managing the translations of numerous independent projects, without the worry of deploying one’s own instance, growing a community and managing the infrastructure.

## Getting started

Overview
  Learn what Transifex is all about.
Installation Guide
  Get Transifex installed on your computer.
Running Transifex
  How to setup your service and keep it running.
FAQ
  Frequently Asked Questions. And answers of course.

## Development

Releases
  See what is and was new in each release of Transifex.
Transifex applications
  Dig around the Transifex applications and API.
Credits
  Who’s behind Transifex?

The full documentation for development and contributing to Transifex can be found at the Develoment wiki, at http://trac.transifex.org/wiki/Development.

## Indices, glossary and tables

- Table of Contents
- Glossary

- Index
- Module Index

## Getting help

Having trouble? We’d like to help!

- Try the FAQ – it’s got answers to many common questions.
- Looking for specific information? Try the Index, Module Index or the detailed table of contents.
- Search for information in the archives of the transifex-devel mailing list, or post a question.
- Ask a question in the #transifex IRC channel.
- Report bugs with Transifex in our ticket tracker.